<?php

	############################################################################
	# 	
	#	Meteotemplate
	# 	http://www.meteotemplate.com
	# 	Free website template for weather enthusiasts
	# 	Author: Jachym
	#           Brno, Czech Republic
	# 	First release: 2015
	#
	############################################################################
	#
	#	Air Traffic
	#
	# 	Map with current plane positions from two different sources.
	#
	############################################################################
	#	Version and change log
	#
	# 	v1.0 - Jun 27, 2017
	# 		- initial release
	# 	v1.1 - Oct 9, 2017
	# 		- bug fixes
	#
	############################################################################
	
	
	include("../../config.php");
	include($baseURL."css/design.php");
	include($baseURL."header.php");

	if(!file_exists("settings.php")){
		echo "Missing settings file, create one using the plugin setup.";
		die();
	}
	else{
		include("settings.php");
	}

	$bgs = array("","#00ccff","#0099cc","#006699","#ffff00","#ffcc00","#ff9933","#ff6666","#ff0000","#cc0000","#990000","#660000","#660000","#660000");
	$fontCols = array("","white","white","white","black","black","black","white","white","white","white","white","white","white");

	createCacheDir();

	if(file_exists("cache/data.txt")){
		if (time()-filemtime("cache/data.txt") > 60 * 60 * 3) {
			unlink("cache/data.txt");
		}
	}

	if(file_exists("cache/data.txt")){
		$html = file_get_contents("cache/data.txt");
	}
	else{
		$sourceURL = "http://weather.gc.ca/airquality/pages/provincial_summary/".$qualityProvince."_e.html";
		$rawHTML = loadContent($sourceURL,8);
		$html = cleanHTML($rawHTML);
	}

	preg_match('/<table class="table table-striped table-hover">(.*?)<\/table>/',$html,$matchedTable);

	$tableHTML = $matchedTable[0];

	$tableHTML = preg_replace('/<a c.*?html">/',"",$tableHTML);
	$tableHTML = preg_replace('/<\/a>/',"",$tableHTML);
	$tableHTML = preg_replace('/<caption>.*?<\/caption>/',"",$tableHTML);
	$tableHTML = preg_replace('/<a href="\/airquality\/pages.*?>/',"",$tableHTML);

	$tableHTML = str_replace("1<br>Low Risk","<div class='quality1'>1<br>Low Risk</div>",$tableHTML);
	$tableHTML = str_replace("2<br>Low Risk","<div class='quality2'>2<br>Low Risk</div>",$tableHTML);
	$tableHTML = str_replace("3<br>Low Risk","<div class='quality3'>3<br>Low Risk</div>",$tableHTML);
	$tableHTML = str_replace("4<br>Moderate Risk","<div class='quality4'>4<br>Moderate Risk</div>",$tableHTML);
	$tableHTML = str_replace("5<br>Moderate Risk","<div class='quality5'>5<br>Moderate Risk</div>",$tableHTML);
	$tableHTML = str_replace("6<br>Moderate Risk","<div class='quality6'>6<br>Moderate Risk</div>",$tableHTML);
	$tableHTML = str_replace("7<br>High Risk","<div class='quality7'>7<br>High Risk</div>",$tableHTML);
	$tableHTML = str_replace("8<br>High Risk","<div class='quality8'>8<br>High Risk</div>",$tableHTML);
	$tableHTML = str_replace("9<br>High Risk","<div class='quality9'>9<br>High Risk</div>",$tableHTML);
	$tableHTML = str_replace("10<br>High Risk","<div class='quality10'>10<br>High Risk</div>",$tableHTML);
	$tableHTML = str_replace("11<br>High Risk","<div class='quality11'>11<br>Very High Risk</div>",$tableHTML);
	$tableHTML = str_replace("12<br>High Risk","<div class='quality12'>12<br>Very High Risk</div>",$tableHTML);
	$tableHTML = str_replace("13<br>High Risk","<div class='quality13'>13<br>Very High Risk</div>",$tableHTML);

	if($lang=="fr"){
		$tableHTML = str_replace("Low Risk","Risque faible",$tableHTML);
		$tableHTML = str_replace("Moderate Risk","Risque modéré",$tableHTML);
		$tableHTML = str_replace("High Risk","Risque élevé",$tableHTML);
		$tableHTML = str_replace("Very High Risk","Risque très élevé",$tableHTML);
		$tableHTML = str_replace("Location and sub-locations","Lieu et sous-lieux",$tableHTML);
		$tableHTML = str_replace("Current Observation","Conditions actuelles",$tableHTML);
		$tableHTML = str_replace("Forecast Maximums","Maximums prévus",$tableHTML);
		$tableHTML = str_replace("Monday",'lundi',$tableHTML);
		$tableHTML = str_replace("Tuesday",'mardi',$tableHTML);
		$tableHTML = str_replace("Wednesday",'mercredi',$tableHTML);
		$tableHTML = str_replace("Thursday",'jeudi',$tableHTML);
		$tableHTML = str_replace("Friday",'vendredi',$tableHTML);
		$tableHTML = str_replace("Saturday",'samedi',$tableHTML);
		$tableHTML = str_replace("Sunday",'dimanche',$tableHTML);
		$tableHTML = str_replace("night",'soir et nuit',$tableHTML);
	}
?>
<!DOCTYPE html>
<html>
	<head>
		<title><?php echo lang('air quality','c')?></title>
		<?php metaHeader()?>
		<style>
			.text-center{
				text-align: center!important;
			}
			.bold{
				font-weight: bold;
				font-variant: small-caps;
			}
			.text-left{
				font-weight: bold;
				font-variant: small-caps;
			}
			<?php 
				for($i=1;$i<14;$i++){
			?>
					.quality<?php echo $i?>{
						padding: 3px;
						border-radius: 4px;
						background: <?php echo $bgs[$i]?>;
						color: <?php echo $fontCols[$i]?>;
					}
			<?php 
				}
			?>
			.table-striped{
				table-layout: fixed;
			}
		</style>
	</head>
	<body>
		<div id="main_top">
			<?php bodyHeader()?>
			<?php include($baseURL."menu.php");?>
		</div>
		<div id="main" style="text-align:center">
			<h1><?php echo lang('air quality','c')?></h1>
			<br>
			<div style="width:98%;margin:0 auto">
				<?php echo $tableHTML?>
			</div>
			<div style="width:98%;margin:0 auto;text-align:left">
				<?php 
					if($lang=="fr"){
						echo "Ce tableau vous offre un sommaire provincial des valeurs actuelles et valeurs maximales prévues1 de la Cote air santé";
					}
					else{
						echo "This table shows a provincial summary of current Air Quality Health Index values and forecast maximums";
					}
				?>	
			</div>
			<br>
			<div style="width:98%;margin:0 auto;font-size:0.8em;text-align:center">
				<?php echo lang('data source','c')?>: Environment Canada
			</div>
			<br><br>
		</div>
		<?php include($baseURL."footer.php");?>
	</body>
</html>